@@ -50,7 +50,7 @@ def run_tests(generator, root, withdata=False, cpp=True, python=True, php=True,
         run('cpp', 'xml', clean_out_dir=False)
     if python:
         generator.model.php_validate = False
-        run('py', 'json', False)
+        run('py', 'json', False, False)
         run('py', 'xml', False)
         with_join and run('py', 'json', True)
         with_join and run('py', 'xml', True)
@@ -61,6 +61,7 @@ def run_tests(generator, root, withdata=False, cpp=True, python=True, php=True,
         with_join and run('php', 'json', True)
         with_join and run('php', 'xml', True)
     if js:
+        generator.model.php_validate = False
         run('js', 'json')
 
 
